@@ -313,3 +313,84 @@ test_that("Ridout - A Comparison of Confidence...", {
   expect_equal(x19$LB, 465.1, tol = .05)
   expect_true(is.infinite(x19$UB))
 })
+
+
+# Bias adjusted point estimate (Salama et al., 1978; Haas, 1989) ----------------
+
+test_that("worksheet bias adjustment example", {
+  x <- mpn(positive = c(5, 3, 0), tubes = c(5, 5, 5), amount = c(10, 1, .1))
+  expect_equal(x$MPN_adj, expected = 0.67, tolerance = .01)
+})
+
+test_that("Salama et al. (1978) adjustment", {
+
+  #What if all positive?
+  x <- mpn(positive = c(2, 2), tubes = c(2, 2), amount = c(1, .1))
+  expect_true(is.infinite(x$MPN))
+  expect_true(is.na(x$MPN_adj))
+
+  #Table 1 (Haas, 1989)
+  my_tubes  <- c(5, 5, 5)
+  my_amount <- c(10, 1, .1)
+  my_tol    <-  .005
+  x1 <- mpn(positive = c(0, 0, 0), tubes = my_tubes, amount = my_amount)
+  expect_equal(x1$MPN, 0, tol = my_tol)
+  expect_equal(x1$MPN_adj, 0, tol = my_tol)
+  x2 <- mpn(positive = c(0, 0, 1), tubes = my_tubes, amount = my_amount)
+  expect_equal(x2$MPN, .02, tol = my_tol)
+  expect_equal(x2$MPN_adj, .02, tol = my_tol)
+  x3 <- mpn(positive = c(0, 1, 0), tubes = my_tubes, amount = my_amount)
+  expect_equal(x3$MPN, .02, tol = my_tol)
+  expect_equal(x3$MPN_adj, .02, tol = my_tol)
+  x4 <- mpn(positive = c(0, 2, 0), tubes = my_tubes, amount = my_amount)
+  expect_equal(x4$MPN, .04, tol = my_tol)
+  expect_equal(x4$MPN_adj, .03, tol = my_tol)
+  x5 <- mpn(positive = c(1, 1, 1), tubes = my_tubes, amount = my_amount)
+  expect_equal(x5$MPN, .06, tol = my_tol)
+  expect_equal(x5$MPN_adj, .05, tol = my_tol)
+  x6 <- mpn(positive = c(3, 2, 0), tubes = my_tubes, amount = my_amount)
+  expect_equal(x6$MPN, .14, tol = my_tol)
+  expect_equal(x6$MPN_adj, .12, tol = my_tol)
+  x7 <- mpn(positive = c(5, 0, 2), tubes = my_tubes, amount = my_amount)
+  expect_equal(x7$MPN, .43, tol = my_tol)
+  expect_equal(x7$MPN_adj, .30, tol = my_tol)
+  x8 <- mpn(positive = c(5, 4, 3), tubes = my_tubes, amount = my_amount)
+  expect_equal(x8$MPN, 2.78, tol = my_tol)
+  expect_equal(x8$MPN_adj, 2.05, tol = my_tol)
+  x9 <- mpn(positive = c(5, 5, 4), tubes = my_tubes, amount = my_amount)
+  expect_equal(x9$MPN, 16.09, tol = my_tol)
+  expect_equal(x9$MPN_adj, 12.09, tol = my_tol)
+
+  #Table 2 (Haas, 1989)
+  my_tubes2  <- c(5, 5, 5, 5)
+  my_amount2 <- c(10, 1, .1, .01)
+  x10 <- mpn(positive = c(0, 0, 0, 0), tubes = my_tubes2, amount = my_amount2)
+  expect_equal(x10$MPN, 0, tol = my_tol)
+  expect_equal(x10$MPN_adj, 0, tol = my_tol)
+  x11 <- mpn(positive = c(0, 0, 1, 0), tubes = my_tubes2, amount = my_amount2)
+  expect_equal(x11$MPN, .02, tol = my_tol)
+  expect_equal(x11$MPN_adj, .02, tol = my_tol)
+  x12 <- mpn(positive = c(1, 2, 0, 0), tubes = my_tubes2, amount = my_amount2)
+  expect_equal(x12$MPN, .06, tol = my_tol)
+  expect_equal(x12$MPN_adj, .05, tol = my_tol)
+  x13 <- mpn(positive = c(3, 1, 1, 0), tubes = my_tubes2, amount = my_amount2)
+  expect_equal(x13$MPN, .14, tol = my_tol)
+  expect_equal(x13$MPN_adj, .12, tol = my_tol)
+  x14 <- mpn(positive = c(5, 2, 1, 1), tubes = my_tubes2, amount = my_amount2)
+  expect_equal(x14$MPN, .92, tol = my_tol)
+  expect_equal(x14$MPN_adj, .80, tol = my_tol)
+  x15 <- mpn(positive = c(5, 5, 4, 4), tubes = my_tubes2, amount = my_amount2)
+  expect_equal(x15$MPN, 34.54, tol = my_tol)
+  expect_equal(x15$MPN_adj, 23.70, tol = my_tol)
+  x16 <- mpn(positive = c(5, 5, 5, 4), tubes = my_tubes2, amount = my_amount2)
+  expect_equal(x16$MPN, 160.94, tol = my_tol)
+  expect_equal(x16$MPN_adj, 120.93, tol = my_tol)
+
+  #Table 5 (Haas, 1989)
+  x17 <- mpn(positive = c(4, 1, 0, 0), tubes = my_tubes2, amount = my_amount2)
+  expect_equal(x17$MPN, .1680, tol = .001)
+  expect_equal(x17$MPN_adj, .1405, tol = .001)
+  x18 <- mpn(positive = c(3, 0, 0, 0), tubes = my_tubes2, amount = my_amount2)
+  expect_equal(x18$MPN, .0777, tol = .001)
+  expect_equal(x18$MPN_adj, .0688, tol = .001)
+})
